create view pg_stats_ext
            (schemaname, tablename, statistics_schemaname, statistics_name,
             statistics_owner, attnames, exprs, kinds, inherited, n_distinct,
             dependencies, most_common_vals, most_common_val_nulls, most_common_freqs,
             most_common_base_freqs)
as
SELECT cn.nspname                                                                   AS schemaname,
       c.relname                                                                    AS tablename,
       sn.nspname                                                                   AS statistics_schemaname,
       s.stxname                                                                    AS statistics_name,
       pg_get_userbyid(s.stxowner)                                                  AS statistics_owner,
       (SELECT array_agg(a.attname ORDER BY a.attnum) AS array_agg
        FROM unnest(s.stxkeys) k(k)
                 JOIN pg_attribute a
                      ON a.attrelid = s.stxrelid AND a.attnum = k.k)                AS attnames,
       pg_get_statisticsobjdef_expressions(s.oid)                                   AS exprs,
       s.stxkind                                                                    AS kinds,
       sd.stxdinherit                                                               AS inherited,
       sd.stxdndistinct                                                             AS n_distinct,
       sd.stxddependencies                                                          AS dependencies,
       m.most_common_vals,
       m.most_common_val_nulls,
       m.most_common_freqs,
       m.most_common_base_freqs
FROM pg_statistic_ext s
         JOIN pg_class c ON c.oid = s.stxrelid
         JOIN pg_statistic_ext_data sd ON s.oid = sd.stxoid
         LEFT JOIN pg_namespace cn ON cn.oid = c.relnamespace
         LEFT JOIN pg_namespace sn ON sn.oid = s.stxnamespace
         LEFT JOIN LATERAL ( SELECT array_agg(pg_mcv_list_items."values")       AS most_common_vals,
                                    array_agg(pg_mcv_list_items.nulls)          AS most_common_val_nulls,
                                    array_agg(pg_mcv_list_items.frequency)      AS most_common_freqs,
                                    array_agg(pg_mcv_list_items.base_frequency) AS most_common_base_freqs
                             FROM pg_mcv_list_items(sd.stxdmcv) pg_mcv_list_items(index, "values", nulls, frequency, base_frequency)) m
                   ON sd.stxdmcv IS NOT NULL
WHERE NOT (EXISTS (SELECT 1
                   FROM unnest(s.stxkeys) k(k)
                            JOIN pg_attribute a
                                 ON a.attrelid = s.stxrelid AND a.attnum = k.k
                   WHERE NOT has_column_privilege(c.oid, a.attnum, 'select'::text)))
  AND (c.relrowsecurity = false OR NOT row_security_active(c.oid));

alter table pg_stats_ext
    owner to postgres;

grant select on pg_stats_ext to public;

