create view pg_stats_ext_exprs
            (schemaname, tablename, statistics_schemaname, statistics_name,
             statistics_owner, expr, inherited, null_frac, avg_width, n_distinct,
             most_common_vals, most_common_freqs, histogram_bounds, correlation,
             most_common_elems, most_common_elem_freqs, elem_count_histogram)
as
SELECT cn.nspname                  AS schemaname,
       c.relname                   AS tablename,
       sn.nspname                  AS statistics_schemaname,
       s.stxname                   AS statistics_name,
       pg_get_userbyid(s.stxowner) AS statistics_owner,
       stat.expr,
       sd.stxdinherit              AS inherited,
       (stat.a).stanullfrac        AS null_frac,
       (stat.a).stawidth           AS avg_width,
       (stat.a).stadistinct        AS n_distinct,
       CASE
           WHEN (stat.a).stakind1 = 1 THEN (stat.a).stavalues1
           WHEN (stat.a).stakind2 = 1 THEN (stat.a).stavalues2
           WHEN (stat.a).stakind3 = 1 THEN (stat.a).stavalues3
           WHEN (stat.a).stakind4 = 1 THEN (stat.a).stavalues4
           WHEN (stat.a).stakind5 = 1 THEN (stat.a).stavalues5
           ELSE NULL::anyarray
           END                     AS most_common_vals,
       CASE
           WHEN (stat.a).stakind1 = 1 THEN (stat.a).stanumbers1
           WHEN (stat.a).stakind2 = 1 THEN (stat.a).stanumbers2
           WHEN (stat.a).stakind3 = 1 THEN (stat.a).stanumbers3
           WHEN (stat.a).stakind4 = 1 THEN (stat.a).stanumbers4
           WHEN (stat.a).stakind5 = 1 THEN (stat.a).stanumbers5
           ELSE NULL::real[]
           END                     AS most_common_freqs,
       CASE
           WHEN (stat.a).stakind1 = 2 THEN (stat.a).stavalues1
           WHEN (stat.a).stakind2 = 2 THEN (stat.a).stavalues2
           WHEN (stat.a).stakind3 = 2 THEN (stat.a).stavalues3
           WHEN (stat.a).stakind4 = 2 THEN (stat.a).stavalues4
           WHEN (stat.a).stakind5 = 2 THEN (stat.a).stavalues5
           ELSE NULL::anyarray
           END                     AS histogram_bounds,
       CASE
           WHEN (stat.a).stakind1 = 3 THEN (stat.a).stanumbers1[1]
           WHEN (stat.a).stakind2 = 3 THEN (stat.a).stanumbers2[1]
           WHEN (stat.a).stakind3 = 3 THEN (stat.a).stanumbers3[1]
           WHEN (stat.a).stakind4 = 3 THEN (stat.a).stanumbers4[1]
           WHEN (stat.a).stakind5 = 3 THEN (stat.a).stanumbers5[1]
           ELSE NULL::real
           END                     AS correlation,
       CASE
           WHEN (stat.a).stakind1 = 4 THEN (stat.a).stavalues1
           WHEN (stat.a).stakind2 = 4 THEN (stat.a).stavalues2
           WHEN (stat.a).stakind3 = 4 THEN (stat.a).stavalues3
           WHEN (stat.a).stakind4 = 4 THEN (stat.a).stavalues4
           WHEN (stat.a).stakind5 = 4 THEN (stat.a).stavalues5
           ELSE NULL::anyarray
           END                     AS most_common_elems,
       CASE
           WHEN (stat.a).stakind1 = 4 THEN (stat.a).stanumbers1
           WHEN (stat.a).stakind2 = 4 THEN (stat.a).stanumbers2
           WHEN (stat.a).stakind3 = 4 THEN (stat.a).stanumbers3
           WHEN (stat.a).stakind4 = 4 THEN (stat.a).stanumbers4
           WHEN (stat.a).stakind5 = 4 THEN (stat.a).stanumbers5
           ELSE NULL::real[]
           END                     AS most_common_elem_freqs,
       CASE
           WHEN (stat.a).stakind1 = 5 THEN (stat.a).stanumbers1
           WHEN (stat.a).stakind2 = 5 THEN (stat.a).stanumbers2
           WHEN (stat.a).stakind3 = 5 THEN (stat.a).stanumbers3
           WHEN (stat.a).stakind4 = 5 THEN (stat.a).stanumbers4
           WHEN (stat.a).stakind5 = 5 THEN (stat.a).stanumbers5
           ELSE NULL::real[]
           END                     AS elem_count_histogram
FROM pg_statistic_ext s
         JOIN pg_class c ON c.oid = s.stxrelid
         LEFT JOIN pg_statistic_ext_data sd ON s.oid = sd.stxoid
         LEFT JOIN pg_namespace cn ON cn.oid = c.relnamespace
         LEFT JOIN pg_namespace sn ON sn.oid = s.stxnamespace
         JOIN LATERAL ( SELECT unnest(pg_get_statisticsobjdef_expressions(s.oid)) AS expr,
                               unnest(sd.stxdexpr)                                AS a) stat
              ON stat.expr IS NOT NULL;

alter table pg_stats_ext_exprs
    owner to postgres;

grant select on pg_stats_ext_exprs to public;

